@@ -8,8 +8,6 @@ import  datetime, \
         time, \
         dateutil.parser
 
-from itertools import izip
-
 
 import logging
 log = logging.getLogger(__name__)
@@ -491,7 +489,7 @@ class ModelArray(object):
     def ball(self):
         desc = self.stations[self.unique_stations]
         centroid = [desc[col].mean() for col in ('X', 'Y', 'Z')]
-        dmax = [np.abs(desc[col] - c).max() for col, c in izip(('X', 'Y', 'Z'), centroid)]
+        dmax = [np.abs(desc[col] - c).max() for col, c in zip(('X', 'Y', 'Z'), centroid)]
 
         return centroid, max(dmax)
 
@@ -504,7 +502,7 @@ class ModelArray(object):
         centroid, radius = self.ball()
         events = self.events[self.col_evtid]
         mask = self.mask
-        for c, col in izip(centroid, ('X', 'Y', 'Z')):
+        for c, col in zip(centroid, ('X', 'Y', 'Z')):
             mask &= (events[col] - c) ** 2 < (radius_factor * radius) ** 2
         nmasked = np.sum(self.mask) - np.sum(mask)
         if log.isEnabledFor(logging.INFO):
@@ -551,7 +549,7 @@ class ModelArray(object):
         mask = self.mask
         events = self.events[self.col_evtid]
         stations = self.stations[self.col_staid]
-        for o, c, l in izip(origin, ('Z', 'Y', 'X'), length):
+        for o, c, l in zip(origin, ('Z', 'Y', 'X'), length):
             mask &= (events[c] > (o +  l * padding)) & (events[c] < (o + l * (1 - padding)))
             mask &= (stations[c] > (o + l * padding)) & (stations[c] < (o + l * (1 - padding)))
         nmasked = np.sum(self.mask) - np.sum(mask)
@@ -611,8 +609,8 @@ class ModelArray(object):
     unique_stations_positions = property(__get_unique_stations_positions__)
 
     def iter_traveltimes(self):
-        for sindex, (staid, evtlst, trglst, ttlst, picklst) in enumerate(izip(*self.split_stations())):
-            for evtid, trgid, tt, pickid in izip(evtlst, trglst, ttlst, picklst):
+        for sindex, (staid, evtlst, trglst, ttlst, picklst) in enumerate(zip(*self.split_stations())):
+            for evtid, trgid, tt, pickid in zip(evtlst, trglst, ttlst, picklst):
                 eindex = np.searchsorted(self.unique_events, evtid)
                 yield (staid, sindex, evtid, eindex, trgid, tt, pickid)
 
