@@ -6,7 +6,7 @@ def dictify(el):
     the same name as the children nodes. A dictionary cannot represent the
     full extent of the XML Standard ... think about it.
     """
-    d = {};
+    d = {}
     d.update(el.attrib)
     for k, l in el.__dict__.iteritems():
         d[k] = [dictify(e) for e in l]
